Skip to contents

This module displays the content of the currently selected experiment and assay, also allowing grouping by mean etc.

Usage

assaydatatableOutput(id)

Arguments

id

Module namespace

Value

output An HTML tag object that can be rendered as HTML using as.character()

Details

Leverages the simpletable module

Examples

assaydatatableOutput("experiment")
#> Error in assaydatatableOutput("experiment"): could not find function "assaydatatableOutput"

# Almost certainly used via application creation

data(airway, package = "airway")
ese <- as(airway, "ExploratorySummarizedExperiment")
eselist <- ExploratorySummarizedExperimentList(ese)
#> Creating ExploratorySummarizedExperimentList object

if (interactive()) {
  app <- prepare_app("assaydatatable", eselist)
  shiny::shinyApp(ui = app$ui, server = app$server)
}