Skip to contents

Generic module to isplay grouped, stacked or overlaid bars for a matrix

Usage

barplotInput(id, default_mode = "stack", allow_select = TRUE)

Arguments

id

Submodule namespace

default_mode

Default bar mode

allow_select

Allow user to choose stack mode?

Value

A list of controls that can be added to a UI definition