Skip to contents

Generic module to isplay grouped, stacked or overlaid bars for a matrix

Usage

barplotOutput(id, height = 400)

Arguments

id

Submodule namespace

height

Height of the plotting space in px

Value

A list of elements that can be included in a panel