Skip to contents

Provides 'Count by'/'Split by' selectors and a bar mode toggle for tallying rows of a data frame by a categorical column, plus an export table for the resulting counts.

Usage

categorycountplotInput(id)

Arguments

id

Submodule namespace

Value

A list of controls that can be added to a UI definition

Examples

categorycountplotInput("categorycount")
#> Error in categorycountplotInput("categorycount"): could not find function "categorycountplotInput"