Check one list is a subset of another and throw an error if not
Source:R/contrasts-validate.R
check_list_is_subset.RdCheck one list is a subset of another and throw an error if not

R/contrasts-validate.R
check_list_is_subset.RdCheck one list is a subset of another and throw an error if not