Skip to contents

Provides a drop-down for picking the plot colour palette. The default is shinyngs' fixed colour-blind-safe palette (see make_color_scale); the remaining choices are RColorBrewer qualitative palettes for users who prefer them.

Usage

colormakerInput(id)

Arguments

id

Submodule namespace

Value

output An HTML tag object that can be rendered as HTML using as.character()

Details

This function provides the form elements to control the display

Examples

colormakerInput("myid")
#> Error in colormakerInput("myid"): could not find function "colormakerInput"