Skip to contents

This module is for making scatter plots comparing pairs of groups defined in a 'contrasts' slot of the ExploratorySummarizedExperimentList

Usage

foldchangeplot(id, eselist)

Arguments

id

Module namespace

eselist

ExploratorySummarizedExperimentList object containing ExploratorySummarizedExperiment objects

Details

This function is called directly, using the same id as its UI counterpart, and wraps its logic in moduleServer() (see example).

Examples

data(airway, package = "airway")
ese <- as(airway, "ExploratorySummarizedExperiment")
eselist <- ExploratorySummarizedExperimentList(ese)
#> Creating ExploratorySummarizedExperimentList object

if (interactive()) {
  foldchangeplot("foldchangeplot", eselist)
  app <- prepare_app("foldchangeplot", eselist)
  shiny::shinyApp(ui = app$ui, server = app$server)
}