Skip to contents

This module is for making scatter plots comparing pairs of groups defined in a 'contrasts' slot of the ExploratorySummarizedExperimentList

Usage

foldchangeplotInput(id, eselist)

Arguments

id

Submodule namespace

eselist

ExploratorySummarizedExperimentList object containing ExploratorySummarizedExperiment objects

Value

output An HTML tag object that can be rendered as HTML using as.character()

Details

Leverages the scatterplot module

Examples

data(airway, package = "airway")
ese <- as(airway, "ExploratorySummarizedExperiment")
eselist <- ExploratorySummarizedExperimentList(ese)
#> Creating ExploratorySummarizedExperimentList object

foldchangeplotInput("myid", eselist)
#> Error in foldchangeplotInput("myid", eselist): could not find function "foldchangeplotInput"

# Almost certainly used via application creation

if (interactive()) {
  app <- prepare_app("foldchangeplot", eselist)
  shiny::shinyApp(ui = app$ui, server = app$server)
}