Skip to contents

This module plots control probes from an illumina microarray experiment.

Usage

illuminaarrayqcOutput(id)

Arguments

id

Submodule namespace

Value

output An HTML tag object that can be rendered as HTML using as.character()

Details

This funcion provides the form elements to control the display

This provides actual plot element for display by applications

Examples

illuminaarrayqcOutput("myid")
#> Error in illuminaarrayqcOutput("myid"): could not find function "illuminaarrayqcOutput"