Skip to contents

Shared by interactive_screeplot and anova_pca_metadata so the two produce identical, identically-ordered labels - required for interactive_pca_variance_heatmap to line the two plots up on a shared x-axis.

Usage

pcLabels(n, fraction_explained = NULL)

Arguments

n

Number of components to label

fraction_explained

Optional numeric vector of percent variance explained by each component. When supplied, each label is suffixed with e.g. " (45%)".

Value

output A character vector of length n