Skip to contents

This provides the form elements to control the pca display, derived from the selectmatrix, scatterplotcontrols, and scatterplot modules.

Usage

pcaInput(id, eselist)

Arguments

id

Submodule namespace

eselist

ExploratorySummarizedExperimentList object containing ExploratorySummarizedExperiment objects

Value

output An HTML tag object that can be rendered as HTML using as.character()

Examples

data(airway, package = "airway")
ese <- as(airway, "ExploratorySummarizedExperiment")
eselist <- ExploratorySummarizedExperimentList(ese)
#> Creating ExploratorySummarizedExperimentList object

pcaInput("pca", eselist)
#> Error in pcaInput("pca", eselist): could not find function "pcaInput"

# Almost certainly used via application creation

if (interactive()) {
  app <- prepare_app("pca", eselist)
  shiny::shinyApp(ui = app$ui, server = app$server)
}