Skip to contents

This module produces a simple table of the colData() in an ExploratorySummarizedExperiment object. If more than one of these objects were specified, a select box should appear to pick the desired one for display.

Usage

rowmetatableOutput(id)

Arguments

id

Module namespace

Value

output An HTML tag object that can be rendered as HTML using as.character()

Details

Leverages the simpletable module

Examples

rowmetatableOutput("experiment")
#> Error in rowmetatableOutput("experiment"): could not find function "rowmetatableOutput"