This module uses Plotly to create scatter plots
(see plot_ly), of both 2D and 3D varieties.
Arguments
- id
Module namespace
Value
output An HTML tag object that can be rendered as HTML using
as.character()
Details
Controls for this module are provided by the scatterplotcontrols
module, which is automatically called if reactives are not supplied to the
server function. This setup allows the same set of controls to power
multiple scatter plots.
Examples
scatterplotInput("pca")
#> Error in scatterplotInput("pca"): could not find function "scatterplotInput"