Skip to contents

This module provides a form element and associated get function for defining how a summary statistic is calculated (probably by mean).

Usage

summarisematrix(id)

Arguments

id

Module namespace

Examples

summarisematrix()
#> Error in summarisematrix(): could not find function "summarisematrix"