Skip to contents

Build a per-gene annotation vector, in genes order, for interactive_topgene_boxplots

Usage

topgeneAnnotationVector(annotations, genes)

Arguments

annotations

Optional named character vector keyed by the values in genes, rendered as a per-facet annotation (e.g. a q value string)

genes

Character vector of row names of assay to facet on, in the order facets should appear. Also used to look up values in assay, so must match its row names even when labels is supplied.

Value

A character vector parallel to genes (NA where no annotation was supplied/matched)