Skip to contents

Make the grid of points indicating set membership in intersections

Usage

upset_grid_plot(sets, ints, nintersects)

Arguments

sets

A named list of character vectors, one per set

ints

A list with combinations and intersections, as returned by upset_calculate_intersections (optionally filtered by upset_filter_intersections_by_order)

nintersects

Maximum number of intersections to display, taken from the front of ints

Value

output A plotly htmlwidget