Skip to contents

A volcano plot displays -log(10) of a p value/ FDR against a log(2) fold change on the x axis. This module produces such a plot using the scatterplot module (which uses plot_ly)), using data provided by the contrasts module based on the setting of contrasts in eselist.

Usage

volcanoplotInput(id, eselist)

Arguments

id

Submodule namespace

eselist

ExploratorySummarizedExperimentList object containing ExploratorySummarizedExperiment objects

Value

output An HTML tag object that can be rendered as HTML using as.character()

Examples

data(airway, package = "airway")
ese <- as(airway, "ExploratorySummarizedExperiment")
eselist <- ExploratorySummarizedExperimentList(ese)
#> Creating ExploratorySummarizedExperimentList object

# The volcano module needs an eselist carrying differential statistics
# (contrast_stats); see the vignette. It is used via application creation:

if (interactive()) {
  volcanoplotInput("myid", eselist)
  app <- prepare_app("volcanoplot", eselist)
  shiny::shinyApp(ui = app$ui, server = app$server)
}