The UI input function of the assaydatatable module
Source:R/assaydatatable.R
assaydatatableInput.RdThis module displays the content of the currently selected experiment and assay, also allowing grouping by mean etc.
Examples
data(airway, package = "airway")
ese <- as(airway, "ExploratorySummarizedExperiment")
eselist <- ExploratorySummarizedExperimentList(ese)
#> Creating ExploratorySummarizedExperimentList object
assaydatatableInput("experiment", eselist)
#> Error in assaydatatableInput("experiment", eselist): could not find function "assaydatatableInput"
# Almost certainly used via application creation
if (interactive()) {
app <- prepare_app("assaydatatable", eselist)
shiny::shinyApp(ui = app$ui, server = app$server)
}