The input function of the chipseq module. Currently a near-clone of the RNA-seq module, with ChIP-seq optimisations planned.
Source:R/chipseq.R
chipseqInput.RdThis provides the form elements to control the ChIP-seq display

R/chipseq.R
chipseqInput.RdThis provides the form elements to control the ChIP-seq display