This module will produce a sample clustering dendrogram based on
user-selected parameters of row (e.g. gene) and column (sample) selection
provided by the selectmatrix module, as well distance matrix
generation and clustering method.
This module will produce a sample clustering dendrogram based on
user-selected parameters of row (e.g. gene) and column (sample) selection
provided by the selectmatrix module, as well distance matrix
generation and clustering method.