This module will produce a sample clustering dendrogram based on
user-selected parameters of row (e.g. gene) and column (sample) selection
provided by the selectmatrix module, as well distance matrix
generation and clustering method.
Examples
library(shinyngs)
data(airway, package = "airway")
ese <- as(airway, "ExploratorySummarizedExperiment")
eselist <- ExploratorySummarizedExperimentList(ese)
#> Creating ExploratorySummarizedExperimentList object
dendroInput("myid", eselist)
#> Error in dendroInput("myid", eselist): could not find function "dendroInput"