The output function of the experimenttable module
Source:R/experimenttable.R
experimenttableOutput.RdThis module produces a simple table of the colData() in an
ExploratorySummarizedExperiment object. If more than one of these objects
were specified, a select box should appear to pick the desired one for
display.
Examples
experimenttableOutput("experiment")
#> Error in experimenttableOutput("experiment"): could not find function "experimenttableOutput"
# Almost certainly used via application creation
data(airway, package = "airway")
ese <- as(airway, "ExploratorySummarizedExperiment")
eselist <- ExploratorySummarizedExperimentList(ese)
#> Creating ExploratorySummarizedExperimentList object
if (interactive()) {
app <- prepare_app("experimenttable", eselist)
shiny::shinyApp(ui = app$ui, server = app$server)
}