Default color table for Ensembl transcript biotypes, used to color the full transcript catalog track loaded by the gene module's gene model view
Source: R/gene.R
geneModelBiotypeColors.RdDefault color table for Ensembl transcript biotypes, used to color the
full transcript catalog track loaded by the gene module's gene
model view