The groupby module provides a UI element to choose from the
group_vars in a SummarizedExperment. Useful for coloring in a PCA etc
Usage
groupby(
id,
eselist,
group_label = "Group by",
multiple = FALSE,
selectColData = NULL,
isDynamic = reactive({
TRUE
})
)Arguments
- id
Module namespace
- eselist
ExploratorySummarizedExperimentList object containing ExploratorySummarizedExperiment objects
- group_label
A label for the grouping field
- multiple
Produces a checkbox group if true, a select box if false
- selectColData
Reactive returning an experiment matrix, probably derived from the
selectmatrixmodule.- isDynamic
Reactive expression providing a boolean. A FALSE value causes the groupby option to be placed in a hidden field.