Guess whether fold change values are on a log2 or linear scale
Source:R/foldchange-scale.R
guess_foldchange_scale.RdShinyngs stores fold changes internally as signed linear values (the ratio
of the two conditions, with an absolute magnitude of at least 1 and the
sign indicating direction - see fold_change), so a value
strictly between -1 and 1 is only possible on a log2 scale (e.g. a log2
fold change of 0.5 is a ~1.4-fold change). log2 fold changes are also
typically small and symmetric around zero, while linear fold changes can
have very large magnitudes for the same effect size (e.g. a 1000-fold
change is a log2 fold change of ~10).