R/selectmatrix.R
linkMatrix.Rd
Root URLs must be present in the url_roots slot of se
url_roots
se
linkMatrix(matrix, url_roots, display_values = data.frame())
The input table
A list with URL roots, with names matching columns of matrix
matrix
A matrix which may contain values for displaying in the link, differerent from that used in the href.
output Table with links added