Shared by interactive_screeplot and
anova_pca_metadata so the two produce
identical, identically-ordered labels - required for
interactive_pca_variance_heatmap to line the two plots up on a
shared x-axis.
Shared by interactive_screeplot and
anova_pca_metadata so the two produce
identical, identically-ordered labels - required for
interactive_pca_variance_heatmap to line the two plots up on a
shared x-axis.