The plotdownload module provides export functionality for panels with plots. This will generally not be called directly, but by other modules
Examples
plotdownload("heatmap", makePlot = plotHeatmap, filename = "heatmap.png", plotHeight = plotHeight, plotWidth = plotWidth)
#> Error in plotdownload("heatmap", makePlot = plotHeatmap, filename = "heatmap.png", plotHeight = plotHeight, plotWidth = plotWidth): could not find function "plotdownload"