Display plots and tables relating to read mapping, attrition during
analysis etc.
Usage
readreportsInput(id, eselist)
Arguments
- id
Submodule namespace
- eselist
ExploratorySummarizedExperiment with read_distribution
slot filled
Value
A list of controls that can be added to a UI definition