Display plots and tables relating to read mapping, attrition during
analysis etc.
Usage
readreportsOutput(id, eselist)
Arguments
- id
Submodule namespace
- eselist
ExploratorySummarizedExperiment with read_distribution
slot filled
Value
A list of elements that can be included in a panel