This module produces a simple table of the colData() in an
ExploratorySummarizedExperiment object. If more than one of these objects
were specified, a select box should appear to pick the desired one for
display.
This module produces a simple table of the colData() in an
ExploratorySummarizedExperiment object. If more than one of these objects
were specified, a select box should appear to pick the desired one for
display.