This module provides controls for selecting matrix columns by sample or group name.
Arguments
- id
Submodule namespace
- eselist
ExploratorySummarizedExperimentList object containing ExploratorySummarizedExperiment objects
- getExperiment
Reactive expression that returns a
ExploratorySummarizedExperimentwith assays and metadata. Usually a result of a user selection- select_samples
Select samples at all? If set to false, a hidden input indicating the selection of all samples is produced.