Given a string with spaces, try to split into multiple lines of < linewidth characters
Source: R/utils-string.R
split_string_to_fixed_width_lines.RdGiven a string with spaces, try to split into multiple lines of <
linewidth characters