This module provides a form element and associated get function for defining how a summary statistic is calculated (probably by mean).
This module provides a form element and associated get function for defining how a summary statistic is calculated (probably by mean).