Summarise the rows of a matrix, applying a function to groups of cells defined by a factor
Source:R/summarisematrix.R
summarize_matrix.RdNote that the specified function will be applied to a tranformed version
of the matrix, so colMeans(), for example, is appropriate.