Build the per-facet annotation data frame used by static_topgene_boxplots
Source: R/topgeneboxplot.R
topgeneAnnotationData.RdBuild the per-facet annotation data frame used by
static_topgene_boxplots
Arguments
- annotations
Optional named character vector keyed by the values in
genes, rendered as a per-facet annotation (e.g. a q value string)- genes
Character vector of row names of
assayto facet on, in the order facets should appear. Also used to look up values inassay, so must match its row names even whenlabelsis supplied.