Reshape an assay matrix into long form for static_topgene_boxplots
Source: R/topgeneboxplot.R
topgeneBoxplotData.RdReshape an assay matrix into long form for static_topgene_boxplots
Arguments
- assay
Numeric matrix, genes (rows) by samples (columns)
- groupby
Vector of group labels, one per column of
assay- genes
Character vector of row names of
assayto facet on, in the order facets should appear. Also used to look up values inassay, so must match its row names even whenlabelsis supplied.- should_transform
A boolean indicating if the log2 transformation should be applied. If TRUE, log2 transformation is applied unconditionally. If FALSE, no transformation is applied. If NULL, a conditional transformation based on threshold is applied.