Make the grid of points indicating set membership in intersections
Source:R/upset.R
upset_grid_plot.RdMake the grid of points indicating set membership in intersections
Arguments
- sets
A named list of character vectors, one per set
- ints
A list with
combinationsandintersections, as returned byupset_calculate_intersections(optionally filtered byupset_filter_intersections_by_order)- nintersects
Maximum number of intersections to display, taken from the front of
ints